@@ -9,7 +9,7 @@ use feature ":5.10";
 use Config;
 use File::Spec::Functions qw(catdir rel2abs splitpath);
 
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 
 use constant DFLT_TOCOPY_SECTION  => "__TOCOPY__";
 
@@ -27,6 +27,7 @@ use constant {EXPANDED          => FLD_KEY_PREFIX . 'EXPANDED',
               SRC_NAME          => FLD_KEY_PREFIX . 'SRC_NAME',
               VARIABLES         => FLD_KEY_PREFIX . 'VARIABLES',
               GLOBAL_VARS       => FLD_KEY_PREFIX . 'GLOBAL_VARS',
+              GLOBAL_MODE       => FLD_KEY_PREFIX . 'GLOBAL_MODE',
               VREF_RE           => FLD_KEY_PREFIX . 'VREF_RE',
               SEPARATOR         => FLD_KEY_PREFIX . 'SEPARATOR',
               BACKUP            => FLD_KEY_PREFIX . 'BACKUP',
@@ -84,7 +85,7 @@ my $_check_not_tocopy = sub {
 
 sub new {
   my ($class, %args) = @_;
-  state $allowed_keys = {map {$_ => undef} qw(tocopy_section tocopy_vars not_tocopy
+  state $allowed_keys = {map {$_ => undef} qw(tocopy_section tocopy_vars not_tocopy global_mode
                                               separator cmnt_vl)};
   _check_args(\%args, $allowed_keys);
   my $self = {};
@@ -105,7 +106,8 @@ sub new {
   $self->{+TOCOPY_SECTION} = $args{tocopy_section} // DFLT_TOCOPY_SECTION;
   $self->$_check_tocopy_vars($args{tocopy_vars}, 1) if exists($args{tocopy_vars});
   $self->$_check_not_tocopy($args{not_tocopy},   1) if exists($args{not_tocopy});
-  return bless($self, $class) ;
+  $self->{+GLOBAL_MODE} = !!$args{global_mode};
+  return bless($self, $class);
 }
 
 
@@ -151,6 +153,7 @@ my $_parse_ini = sub {
   my $variables   = $self->{+VARIABLES};
   my $tocopy_sec  = $self->{+TOCOPY_SECTION};
   my $tocopy_vars = $variables->{$tocopy_sec}; # hash key need not to exist!
+  my $global_mode = $self->{+GLOBAL_MODE};
 
   my $tocopy_sec_declared;
 
@@ -164,7 +167,7 @@ my $_parse_ini = sub {
       $tocopy_vars = $variables->{$tocopy_sec} = {} if !$tocopy_vars;
       $tocopy_sec_declared = 1;
     }
-    elsif ($tocopy_vars) {
+    elsif ($tocopy_vars && !$global_mode) {
       $self->$_cp_tocopy_vars($curr_section);
     }
     else {
@@ -250,7 +253,7 @@ sub parse_ini {
   foreach my $scalar_arg (qw(tocopy_section src_name)) {
      croak("'$scalar_arg': must not be a reference") if ref($args{$scalar_arg});
    }
-  delete $self->{+SRC_NAME} if exists($self->{+SRC_NAME});  #### !!!!!!!!!!!
+  delete $self->{+SRC_NAME} if exists($self->{+SRC_NAME});
   $self->{+SRC_NAME} = $args{src_name} if exists($args{src_name});
   my (      $cleanup, $src, $tocopy_section, $tocopy_vars, $not_tocopy) =
     @args{qw(cleanup   src   tocopy_section   tocopy_vars   not_tocopy)};
@@ -330,9 +333,17 @@ sub parse_ini {
                                                              !%$tocopy_sec_vars);
   }
   else {
-    while (my ($section, $variables) = each(%{$self->{+VARIABLES}})) {
-      $variables->{'='} = $section;
-      @{$variables}{keys(%$global_vars)} = values(%$global_vars);
+    if ($self->{+GLOBAL_MODE}) {
+      while (my ($section, $sec_vars) = each(%{$self->{+VARIABLES}})) {
+        $sec_vars->{'='} = $section;
+      }
+      @{$tocopy_sec_vars}{keys(%$global_vars)} = values(%$global_vars);
+    }
+    else {
+      while (my ($section, $sec_vars) = each(%{$self->{+VARIABLES}})) {
+        $sec_vars->{'='} = $section;
+        @{$sec_vars}{keys(%$global_vars)} = values(%$global_vars);
+      }
     }
   }
   $self->{+TOCOPY_SECTION} = $backup->{tocopy_section} if exists($backup->{tocopy_section});
@@ -344,12 +355,12 @@ sub parse_ini {
 
 
 sub current_tocopy_section {$_[0]->{+CURR_TOCP_SECTION}}
+sub tocopy_section  {$_[0]->{+TOCOPY_SECTION}}
+sub global_mode     {$_[0]->{+GLOBAL_MODE}}
 sub sections        { defined($_[0]->{+SECTIONS})   ? [@{$_[0]->{+SECTIONS}}]     : undef}
 sub sections_h      { defined($_[0]->{+SECTIONS_H}) ? +{ %{$_[0]->{+SECTIONS_H}} } : undef }
 sub separator       {$_[0]->{+SEPARATOR}}
 sub src_name        {$_[0]->{+SRC_NAME}}
-sub tocopy_section  {$_[0]->{+TOCOPY_SECTION}}
-
 sub variables       { my $vars = $_[0]->{+VARIABLES} // return undef;
                       return  {map {$_ => {%{$vars->{$_}}}} keys(%$vars)};
                     }
@@ -361,6 +372,7 @@ $_look_up = sub {
   my ($v_section, $v_basename) = $matched ? ($1, $2) : ($curr_sect, $variable);
   my $v_value;
   my $variables = $self->{+VARIABLES};
+  my $tocopy_section = $self->{+TOCOPY_SECTION};
   if (!exists($variables->{$v_section})) {
     $v_value = "";
   } elsif ($v_basename !~ /\S/) {
@@ -375,6 +387,14 @@ $_look_up = sub {
   elsif (exists($self->{+GLOBAL_VARS}{$v_basename})) {
     $v_value = $self->{+GLOBAL_VARS}{$v_basename};
   }
+  elsif ($self->{+GLOBAL_MODE} && exists($variables->{$tocopy_section}{$v_basename})) {
+    if (!$matched && $curr_sect ne $tocopy_section && exists($self->{+NOT_TOCOPY}{$v_basename})) {
+      $v_value = "";
+    }
+    else {
+      $v_value = $variables->{$tocopy_section}{$v_basename};
+    }
+  }
   else {
     if (exists($variables->{$v_section}{$v_basename})) {
       $v_value = $variables->{$v_section}{$v_basename};
@@ -472,7 +492,7 @@ Config::INI::RefVars - INI file reader, allows the referencing of INI and enviro
 
 =head1 VERSION
 
-Version 0.07
+Version 0.08
 
 =head1 SYNOPSIS
 
@@ -936,10 +956,14 @@ value C<$(var)> and you write this in your INI file:
 This results in C<x> having the value C<$(var)>, while C<y> has the value C<hello!>.
 
 
-=head2 THE I<TOCOPY> SECTION
+=head2 THE SECTION I<TOCOPY>
 
-If specified, the C<parse_ini> method copies the variables of the I<tocopy
-section> to every other section when the INI file is read. For example this
+=head3 Default Behavior
+
+If specified, the method C<parse_ini> copies the variables of the section
+I<tocopy> to any other section when the INI file is read (default, this
+behavior can be changed by the constructor argument C<global_mode>).
+For example this
 
    [__TOCOPY__]
    some var=some value
@@ -996,6 +1020,38 @@ C<new> and C<parse_ini>), these are treated as if they were at the very
 beginning of the C<tocopy> section.
 
 
+=head3 Global Mode
+
+If you specify the constructor argument C<global_mode> with a I<true> value,
+the variables of the I<tocopy> section are not copied, but behave like global
+variables. Variables that you specify with the argument C<not_tocopy> are not
+treated as global.
+
+As a result, there is no difference in referencing variables if you use globale mode. The benefit of this mode is that you do not mess up your sections with unwanted variables.
+
+Example:
+
+   [__TOCOPY__]
+   a=this
+   b=that
+
+   [sec]
+   x=y
+
+This would lead to this result by default:
+
+   {
+     __TOCOPY__ => {a => 'this', b => 'that'},
+     sec        => {a => 'this', b => 'that', x => 'y'}
+   }
+
+But in global mode the result is:
+
+   {
+     __TOCOPY__ => {a => 'this', b => 'that'},
+     sec        => {x => 'y'}
+   }
+
 =head2 COMMENTS
 
 As said, if the first non-white character of a line is a C<;> or a C<#>, then the line
@@ -1074,6 +1130,11 @@ The constructor takes the following optional named arguments:
 
 =over
 
+=item C<global_mode>
+
+Optional, a boolean. Cheanges handling of the I<tocopy> section, see section
+L</"GLOBAL MODE">. See also the accessor method of the same name.
+
 =item C<not_tocopy>
 
 Optional, a reference to a hash or an array of strings. The hash keys or array
@@ -1158,6 +1219,12 @@ present in the data.
 See also method C<tocopy_section>.
 
 
+=head3 global_mode
+
+Returns a boolean value indicating whether the global mode is activated or
+not. See constructor argument of the same name, see also section L</"GLOBAL
+MODE">.
+
 =head3 parse_ini
 
 Parses an INI source. The method takes the following optional named arguments:
@@ -1175,7 +1242,8 @@ directly.
 
 Optional, a boolean. If this value is set to I<false>, variables with a C<=>
 in their name are not removed from the resulting hash that is returned by the
-C<variables> method.
+C<variables> method. But in global mode, most of this variables will not be
+contained, see section L</"Global Mode">.
 
 Default is 1 (I<true)>
 
@@ -1263,7 +1331,8 @@ as follows:
 
    my $obj = Config::INI::RefVars->new(separator      => "\\",
                                        cmnt_vl        => 1,
-                                       tocopy_section => 'Settings');
+                                       tocopy_section => 'Settings',
+                                       global_mode    => 1);
    my $src = <<'EOT';
      [Settings]
      BaseDir="d:\dhcpsrv" ; dhcpsrv.exe resides here
